@@ -302,3 +302,22 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         url_path = starlite_instance.route_reverse(name, **path_parameters)
 
         return URLPath(url_path).make_absolute_url(self.base_url)
+
+    def url_for_static_asset(self, name: str, file_path: str) -> str:
+        """Receives a static files handler name, an asset file path and returns
+        resolved absolute url to the asset.
+
+        Args:
+            name: A static handler unique name.
+            file_path: a string containing path to an asset.
+
+        Raises:
+            NoRouteMatchFoundException: If static files handler with 'name' does not exist.
+
+        Returns:
+            A string representing absolute url to the asset.
+        """
+        starlite_instance = self.scope["app"]
+        url_path = starlite_instance.url_for_static_asset(name, file_path)
+
+        return URLPath(url_path).make_absolute_url(self.base_url)
