@@ -6,9 +6,20 @@ from .exception import (
     get_exception_handler,
 )
 from .extractors import ConnectionDataExtractor, ResponseDataExtractor, obfuscate
-from .model import convert_dataclass_to_model, create_parsed_model_field
+from .model import (
+    convert_dataclass_to_model,
+    convert_typeddict_to_model,
+    create_parsed_model_field,
+)
 from .path import join_paths, normalize_path
-from .predicates import is_async_callable, is_class_and_subclass, is_optional_union
+from .predicates import (
+    is_async_callable,
+    is_class_and_subclass,
+    is_dataclass_class_or_instance_typeguard,
+    is_dataclass_class_typeguard,
+    is_optional_union,
+    is_typeddict_typeguard,
+)
 from .scope import get_serializer_from_scope
 from .sequence import find_index, unique
 from .serialization import default_serializer
@@ -22,6 +33,7 @@ __all__ = (
     "as_async_callable_list",
     "async_partial",
     "convert_dataclass_to_model",
+    "convert_typeddict_to_model",
     "create_exception_response",
     "create_parsed_model_field",
     "default_serializer",
@@ -30,8 +42,11 @@ __all__ = (
     "get_serializer_from_scope",
     "is_async_callable",
     "is_class_and_subclass",
+    "is_dataclass_class_or_instance_typeguard",
+    "is_dataclass_class_typeguard",
     "is_dependency_field",
     "is_optional_union",
+    "is_typeddict_typeguard",
     "join_paths",
     "normalize_path",
     "obfuscate",
